==> mysql-8.0_8.0.45.orig.tar.gz: mysql-8.0.45/router/src/destination_status/include/mysqlrouter/supported_destination_status_options.h <==
/*
  Copyright (c) 2022, 2025, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is designed to work with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have either included with
  the program or referenced in the documentation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MYSQLROUTER_ROUTING_SUPPORTED_DESTINATION_STATUS_OPTIONS_INCLUDED
#define MYSQLROUTER_ROUTING_SUPPORTED_DESTINATION_STATUS_OPTIONS_INCLUDED

#include <array>

static constexpr std::array<const char *, 2>
    destination_status_supported_options{"error_quarantine_interval",
                                         "error_quarantine_threshold"};

#endif /* MYSQLROUTER_ROUTING_SUPPORTED_DESTINATION_STATUS_OPTIONS_INCLUDED */

==> mysql-8.0.32.tar.gz: mysql-8.0.32/router/src/destination_status/include/mysqlrouter/supported_destination_status_options.h <==
/*
  Copyright (c) 2022, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef MYSQLROUTER_ROUTING_SUPPORTED_DESTINATION_STATUS_OPTIONS_INCLUDED
#define MYSQLROUTER_ROUTING_SUPPORTED_DESTINATION_STATUS_OPTIONS_INCLUDED

#include <array>

static constexpr std::array<const char *, 2>
    destination_status_supported_options{"error_quarantine_interval",
                                         "error_quarantine_threshold"};

#endif /* MYSQLROUTER_ROUTING_SUPPORTED_DESTINATION_STATUS_OPTIONS_INCLUDED */
